-- Lua Sinus widget

local translations = {en="Lua Sinus", fr="Sinus Lua"}

local function name(widget)
    local locale = system.getLocale()
    return translations[locale] or translations["en"]
end

local sportSensor = sport.getSensor({appIdStart=0x800, appIdEnd=0x51FF})

local function telemetryPop()
  local frame = sportSensor:popFrame()
  if frame == nil then
    return nil, nil, nil, nil
  end
  return frame:physId(), frame:primId(), frame:appId(), frame:value()
end

local function create()
    return {color=lcd.RGB(0, 0, 255)}
end

local function paint(widget)
    local w, h = lcd.getWindowSize()
    lcd.drawLine(0, h/2, w, h/2)
    lcd.color(widget.color)
    for i = 0,w do
      local val = math.sin(i*math.pi/(w/2))
      lcd.drawPoint(i, val*h/2+h/2)
    end
end

local function wakeup(widget)
  local physId, primId, appId, value = telemetryPop()
  print("wakeup", physId, primId, appId, value)
end

local function init()
    system.registerWidget({key="sinus", name=name, create=create, paint=paint, wakeup=wakeup})
end

return {init=init}
